==> org.polarsys.kitalpha.emde.xmi.source_1.2.2.201812041251.jar: org/polarsys/kitalpha/emde/xmi/XMLExtensionHelperImpl.java <==
/*******************************************************************************
 * Copyright (c) 2014 Thales Global Services S.A.S.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 * Contributors:
 *   Thales Global Services S.A.S - initial API and implementation
 *******************************************************************************/
package org.polarsys.kitalpha.emde.xmi;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.xmi.DanglingHREFException;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.emf.ecore.xmi.impl.XMLHelperImpl;

/**
 * @author Xavier Maysonnave
 * 
 */
public class XMLExtensionHelperImpl extends XMLHelperImpl {

	private SAXExtensionXMLHandler handler;

	public XMLExtensionHelperImpl() {
		super();
	}

	public XMLExtensionHelperImpl(XMLResource resource) {
		super(resource);
	}

	public void setXMLHandler(SAXExtensionXMLHandler handler) {
		this.handler = handler;
	}

	@Override
	protected URI handleDanglingHREF(EObject object) {
		if (XMLResource.OPTION_PROCESS_DANGLING_HREF_DISCARD.equals(processDanglingHREF) == false) {
			DanglingHREFException exception = new DanglingHREFException("The object '" + object + "' is not contained in a resource.", //$NON-NLS-1$ //$NON-NLS-2$ 
					resource == null || resource.getURI() == null ? "unknown" : resource.getURI().toString(), //$NON-NLS-1$
					handler != null && handler.getLineNumber() != -1 ? handler.getLineNumber() : 0, handler != null && handler.getColumnNumber() != -1 ? handler.getColumnNumber() : 0);
			if (danglingHREFException == null) {
				danglingHREFException = exception;
			}
			if (resource != null) {
				resource.getErrors().add(exception);
			}
		}
		return null;
	}

}

==> org.polarsys.kitalpha.emde.xmi.source_1.4.0.201910211249.jar: org/polarsys/kitalpha/emde/xmi/XMLExtensionHelperImpl.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2018 Thales Global Services S.A.S.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 * Contributors:
 *   Thales Global Services S.A.S - initial API and implementation
 *******************************************************************************/
package org.polarsys.kitalpha.emde.xmi;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.xmi.DanglingHREFException;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.emf.ecore.xmi.impl.XMLHelperImpl;

/**
 * @author Xavier Maysonnave
 * 
 */
public class XMLExtensionHelperImpl extends XMLHelperImpl {

	private SAXExtensionXMLHandler handler;

	public XMLExtensionHelperImpl() {
		super();
	}

	public XMLExtensionHelperImpl(XMLResource resource) {
		super(resource);
	}

	public void setXMLHandler(SAXExtensionXMLHandler handler) {
		this.handler = handler;
	}

	@Override
	protected URI handleDanglingHREF(EObject object) {
		if (!XMLResource.OPTION_PROCESS_DANGLING_HREF_DISCARD.equals(processDanglingHREF)) {
			DanglingHREFException exception = new DanglingHREFException("The object '" + object + "' is not contained in a resource.", //$NON-NLS-1$ //$NON-NLS-2$ 
					resource == null || resource.getURI() == null ? "unknown" : resource.getURI().toString(), //$NON-NLS-1$
					handler != null && handler.getLineNumber() != -1 ? handler.getLineNumber() : 0, handler != null && handler.getColumnNumber() != -1 ? handler.getColumnNumber() : 0);
			if (danglingHREFException == null) {
				danglingHREFException = exception;
			}
			if (resource != null) {
				resource.getErrors().add(exception);
			}
		}
		return null;
	}

}
